@@ -12,7 +12,7 @@ from peewee_aio.manager import Manager, cached_property
 from .fields import JSONField, Choices
 
 
-__version__ = "0.0.10"
+__version__ = "0.1.0"
 __project__ = "muffin-peewee-aio"
 __author__ = "Kirill Klenov <horneds@gmail.com>"
 __license__ = "MIT"
@@ -149,10 +149,6 @@ class Plugin(BasePlugin):
 
         return middleware
 
-    async def conftest(self):
-        """Prepare database tables for tests."""
-        await self.create_tables()
-
     @cached_property
     def Model(self) -> AIOModel:
         """Generate base async model class."""
